-- Lazy

local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
    vim.fn.system({
        "git",
        "clone",
        "--filter=blob:none",
        "https://github.com/folke/lazy.nvim.git",
        "--branch=stable", -- latest stable release
        lazypath,
    })
end
vim.opt.rtp:prepend(lazypath)

return require('lazy').setup({
    {
        "folke/lazy.nvim",
        tag = "stable",
    },
    {
        "folke/todo-comments.nvim",
        dependencies = { "nvim-lua/plenary.nvim" },
        opts = {
            -- your configuration comes here
            -- or leave it empty to use the default settings
            -- refer to the configuration section below
        }
    },
    { 
        "catppuccin/nvim", 
        name = "catppuccin", 
        priority = 1000 
    },
    -- colors
    {
        "nvim-treesitter/nvim-treesitter",
        build = ":TSUpdate",
    },
    {
        'VonHeikemen/lsp-zero.nvim',
        branch = 'v3.x',
        dependencies = {
            -- LSP Support
            "neovim/nvim-lspconfig",             -- Required
            'williamboman/mason.nvim',           -- Optional
            'williamboman/mason-lspconfig.nvim', -- Optional

            -- Autocompletion
            'hrsh7th/nvim-cmp',         -- Required
            'hrsh7th/cmp-nvim-lsp',     -- Required
            'hrsh7th/cmp-buffer',       -- Optional
            'hrsh7th/cmp-path',         -- Optional
            'saadparwaiz1/cmp_luasnip', -- Optional
            'hrsh7th/cmp-nvim-lua',     -- Optional

            -- Snippets
            'L3MON4D3/LuaSnip',             -- Required
            'rafamadriz/friendly-snippets', -- Optional
        }
    },
    -- navigation
    {
        "nvim-telescope/telescope.nvim", 
        tag = '0.1.8',
        dependencies = { "nvim-lua/plenary.nvim" },
    },
    {
        "ThePrimeagen/harpoon",
        branch = "harpoon2",
        dependencies = { "nvim-lua/plenary.nvim" },
    },
    -- focus plugins
    {
        "folke/twilight.nvim",
        opts = {
            dimming = {
                alpha = 0.25, 
                color = { "Normal", "#ffffff" },
                term_bg = "#000000", 
                inactive = false, 
            },
            context = 10, 
            treesitter = true, 
            expand = { 
                "function",
                "method",
                "table",
                "if_statement"
            },
        },
    },
    {
        "folke/zen-mode.nvim",
        opts = {
            {
                window = {
                    backdrop = 0.95, 
                    width = 120, 
                    height = 1, 
                },
                plugins = {
                    options = {
                        enabled = true,
                        ruler = false, 
                        showcmd = false, 
                    },
                    twilight = { enabled = true }, 
                },
                on_open = function(win)
                end,
                on_close = function()
                end,
            }
        }
    },
    -- obsidian
    {
        "epwalsh/obsidian.nvim",
        version = "v3.2.0",
        lazy = true,
        ft = "markdown",
        dependencies = {
            "nvim-lua/plenary.nvim",
        },
        opts = {
            workspaces = {
                {
                    name = "trinote",
                    path = "~/sync/obsidian/Trinote/",
                },
            },
            disable_frontmatter = true,
        },
        ui = {
            enable = true
        }
    },
    -- ollama
    {
        "nomnivore/ollama.nvim",
        dependencies = {
            "nvim-lua/plenary.nvim",
        },

        -- All the user commands added by the plugin
        cmd = { "Ollama", "OllamaModel", "OllamaServe", "OllamaServeStop" },

        keys = {
            -- Sample keybind for prompt menu. Note that the <c-u> is important for selections to work properly.
            {
                "<leader>oo",
                ":<c-u>lua require('ollama').prompt()<cr>",
                desc = "ollama prompt",
                mode = { "n", "v" },
            },

            -- Sample keybind for direct prompting. Note that the <c-u> is important for selections to work properly.
            {
                "<leader>oG",
                ":<c-u>lua require('ollama').prompt('Generate_Code')<cr>",
                desc = "ollama Generate Code",
                mode = { "n", "v" },
            },
        },

        ---@type Ollama.Config
        opts = {
            model = "codellama",
            url = "factory.lan:11434",
            serve = {
                on_start = false,
                command = "ollama",
                args = { "serve" },
                stop_command = "pkill",
                stop_args = { "-SIGTERM", "ollama" },
            },
            -- View the actual default prompts in ./lua/ollama/prompts.lua
            prompts = {
                Sample_Prompt = {
                    prompt = "This is a sample prompt that receives $input and $sel(ection), among others.",
                    input_label = "> ",
                    model = "mistral",
                    action = "display",
                }
            }
        }
    }
})
